
"""
This module is use to hadle custom errors needed for AWS Batch.
Logger module is added to manage logs as well
"""
from YOMLogger import YOMLogger

class YOMError(Exception):
    """
    Args: 
        message: the message to display
    """
    def __init__(self, message) -> None:
        self.message = message
        self.logger = YOMLogger('YOM-PIP-ERRORS')
        self.logger.error(message)
        super().__init__(message)




class ApiResponseError(Exception):
    """
        Exception raised when yom api service return an error
        Attributes:
            name -- error name
            status_code -- http response error code
    """
    def __init__(self, url, message='Error YOM API'):
        self.url = url
        self.message = message




class ImporterError(Exception):
    """
        Exception raised when yom api service return an error
        Attributes:
            name -- error name
            status_code -- http response error code
    """
    def __init__(self, message, status=None, data=None):
        self.message = message
        self.status = status
        self.data = data



class SaveS3FileError(Exception):
    """
        Exception raised when save a file with data loaded return an error
        Attributes:
            bucket -- name of the bucket that file represents
            filename -- name of the file
    """
    def __init__(self, bucket, filename):
        self.bucket = bucket
        self.filename = filename



from datetime import datetime

class FileNotFoundError(Exception):
    """
        Exception raised when file does not exists.
        Attributes:
            file -- name of the file that file represents
            date -- 
    """
    def __init__(self, file, date=datetime.now()):
        self.file = file
        self.date = date
        
    def __str__(self):
        return f"No files found for {self.file} on date {self.date}."




from distutils.core import setup
setup(
  name = 'YOMErrors',
  packages = ['YOMErrors'],
  version = '0.0.3',
  license='MIT',
  description = 'A PACKAGE TO HANDLE AN ERRORS STANDARD FROM YOM INTEGRATIONS',
  author = 'Camilo Jiménez',
  author_email = 'camilo@youorder.me',
  url = 'https://github.com/user/reponame',
  # download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz', 
  keywords = ['YOM-INTEGRATIONS'],   # Keywords that define your package best
  install_requires=[

  ],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
  python_requires='>=3.6',
)


from YOMErrors.ApiResponseError import ApiResponseError
from YOMErrors.ClientResponseError import ClientResponseError
from YOMErrors.FileNotFoundError import FileNotFoundError
from YOMErrors.FormatColumnsError import FormatColumnsError
from YOMErrors.SaveS3FileError import SaveS3FileError
from YOMErrors.ImporterError import ImporterError



from YOMLogger import YOMLogger

class FormatColumnsError(Exception):
    """
        Exception raised when column of file does not exists.
        Attributes:
            file -- name of the file
            column -- list of dicts that contains now valid columns and current type vs valid type
            column --> ex: [{columnName: 'clientId', currentType: 'integer', validType: 'string'}}]
    """
    def __init__(self, file, columns):
        self.file = file
        self.columns = columns
        self.logger = YOMLogger()
        self.logger.error(self.__str__())

    def __str__(self):
        error_message = ''
        for column in self.columns:
            error_message += f"\n Column {column['columnName']} must be: {column['validType']}, received: {column['currentType']}"

        return error_message



class ClientResponseError(Exception):
    """
        Exception raised when client service return an error
        Attributes:
            url -- url name, ex: www.movilvendor.com/api/get/clients
            status_code -- http response error code
    """
    def __init__(self, url, status_code):
        self.url = url
        self.status_code = status_code
